FID_IID_to_rownames: Assign rownames of phenotype data frame based on FID and IID

Description Usage Arguments Value Examples

View source: R/helpers.R

Description

Given a data frame of the phenotype data, concatenate FID and IID columns with a separater character (sep) and use it as a rowname

Usage

1
FID_IID_to_rownames(pheno_df, sep = "_")

Arguments

pheno_df

A phenotype data frame with columns named 'FID' and 'IID'

sep

A separater to concatenate FID and IID

Value

an updated phenotype data drame with rownames

Examples

1
2
3
4
## Not run: 
FID_IID_to_rownames(pheno_df)

## End(Not run)

rivas-lab/snpnet documentation built on Dec. 14, 2021, 3:22 a.m.