read_lambda_sequence_from_RData_file: Load a lambda sequence from a R Data file

Description Usage Arguments Value

View source: R/fileIO.R

Description

Read a R data file (saved from a snpnet run with validation set) and load the lambda sequence up to the optimal lambda index This helper function is useful to for refit of the snpnet model using the individuals in combined set of training and validation sets.

Usage

1

Arguments

rdata_f

a file path to a R Data file

Value

lambda sequence


rivas-lab/snpnet documentation built on Dec. 14, 2021, 3:22 a.m.