Description Usage Arguments Value
Read a R data file (saved from a snpnet run with validation set) and load the lambda sequence up to the optimal lambda index This helper function is useful to for refit of the snpnet model using the individuals in combined set of training and validation sets.
1 | read_lambda_sequence_from_RData_file(rdata_f)
|
rdata_f |
a file path to a R Data file |
lambda sequence
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.